(sim_events)=

# Simulation Event I/O and Processing Utilities

Modules for handling event-level data generated by the CORSIKA and sim_telarray simulation packages.
Provide tools for reading, writing, and processing simulated shower and telescope events.

## Reader

(sim_events_reader-1)=

```{eval-rst}
.. automodule:: simtools.sim_events.reader
   :members:
```

## File info and headers

(sim_events_file_info)=

```{eval-rst}
.. automodule:: simtools.sim_events.file_info
   :members:
```

## Writer

(sim_events_writer-1)=

```{eval-rst}
.. automodule:: simtools.sim_events.writer
   :members:
```

## Histograms

(sim_events_histograms-1)=

```{eval-rst}
.. automodule:: simtools.sim_events.histograms
   :members:
```
